@@ -17,8 +17,7 @@ from django.core.handlers.wsgi import WSGIHandler
  
 from gunicorn.arbiter import Arbiter
 from gunicorn.config import Config
-from gunicorn.main import daemonize, UMASK, configure_logging
-from gunicorn.util import parse_address, to_bytestring
+from gunicorn.main import daemonize, configure_logging
  
 class Command(BaseCommand):
     option_list = BaseCommand.option_list + (
@@ -53,8 +52,7 @@ class Command(BaseCommand):
             
         options['bind'] = addrport or '127.0.0.1'
         
-        if not options.get('proc_name'):
-            options['proc_name'] =settings.SETTINGS_MODULE
+        options['default_proc_name'] =settings.SETTINGS_MODULE
         conf = Config(options, options.get('gconfig'))
 
         admin_media_path = options.get('admin_media_path', '')
@@ -69,8 +67,7 @@ class Command(BaseCommand):
  
         # django.core.management.base forces the locale to en-us.
         translation.activate(settings.LANGUAGE_CODE)
- 
- 
+        
         try:
             handler = AdminMediaHandler(WSGIHandler(), admin_media_path)
             arbiter = Arbiter(conf.address, conf.workers, handler,
