@@ -3,7 +3,6 @@
 # This file is part of gunicorn released under the MIT license. 
 # See the NOTICE for more information.
 
-import array
 import ctypes
 import fcntl
 import os
@@ -22,7 +21,7 @@ timeout_default = object()
 
 CHUNK_SIZE = (16 * 1024)
 
-MAX_BODY = 1024 * (80 + 32)
+MAX_BODY = 1024 * 132
 
 weekdayname = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']
 monthname = [None,
@@ -89,15 +88,6 @@ def close(sock):
         sock.close()
     except socket.error:
         pass
-  
-def read_partial(sock, length, buf=None):
-    tmp_buf = array.array("c", '\0' * length)
-    l = sock.recv_into(tmp_buf, length)
-    
-    if not buf:
-        return tmp_buf[:l]
-    
-    return buf + tmp_buf[:l]
 
 def write_chunk(sock, data):
     chunk = "".join(("%X\r\n" % len(data), data, "\r\n"))
@@ -137,7 +127,7 @@ def write_error(sock, msg):
     </html>
     """) % msg
     http = textwrap.dedent("""\
-    HTTP/1.0 500 Internal Server Error\r
+    HTTP/1.1 500 Internal Server Error\r
     Connection: close\r
     Content-Type: text/html\r
     Content-Length: %d\r
