@@ -160,7 +160,7 @@ class Worker(object):
                 self.log.exception("Error processing request.")
             else:
                 self.log.warn("Ignoring EPIPE")
-        except UnexpectedShutdown:
+        except UnexpectedEOF:
             self.log.exception("remote closed the connection unexpectedly.")
         except Exception, e:
             self.log.exception("Error processing request.")
